/*****************************************************************************/
/*                                                                           */
/* UNIT: NTL0_Full_Runs  (Level 0 library routine)                           */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    25 JUL 97   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure implements the linear-time algorithm for locating full runs   */
/* within the given array of real numbers (scores); sets up the arrays       */
/* provided in the list of parameters                                        */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl0.h"


#define INFINITY                     31284
#define NEGATIVE                     '-'
#define POSITIVE                     '+'



/*****************************************************************************/

void NTL0_Full_Runs (float *sigma, long int size, long int *count,
                     long int *low, long int *high, float *low_score,
                     float *high_score)
{
 float cumulative, prev; char track; long int p; long int *lower, scan;

 lower = (long int *) NTL0_ckalloc (size * sizeof (long int));
 
 *count = -1; cumulative = 0.0; track = NEGATIVE; sigma [size] = -INFINITY;

 for (p = 0; p <= size; p++) {
  prev = cumulative; cumulative += sigma [p];

  if ((sigma [p] >= 0.0) && (track == NEGATIVE)) {
   track = POSITIVE;
   (*count)++; low [*count] = p; low_score [*count] = prev;
   lower [*count] = (*count) - 1;
   while ((lower [*count] >= 0) && (low_score [lower [*count]] > prev))
    lower [*count] = lower [lower [*count]];
  } 
  else if ((sigma [p] < 0.0) && (track == POSITIVE)) {
   track = NEGATIVE;
   high [*count] = p - 1; high_score [*count] = prev;
   scan = lower [*count];
   while ((scan >= 0) && (high_score [scan] <= prev)) {
    high [scan] = high [*count];
    high_score [scan] = high_score [*count];
    *count = scan; scan = lower [*count];
   }
  }
 }
 free (lower); (*count)++;
}

