/*****************************************************************************/
/*                                                                           */
/* UNIT: NTL1_Consensus_Column  (Level 1 library routine)                    */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    25 JUL 97   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure decides the consensus character for the given string of       */
/* characters (column), based on the majority occurence and guidelines       */
/* about the treatment of gaps; returns the consensus character, '\0' for    */
/* empty string                                                              */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl1.h"


/*****************************************************************************/

char NTL1_Consensus_Column (char *column, int length, int gaps_treatment)
{
 int na, nc, ng, nt, no, ngap, total, index; bool single; char amb;
 
 if (length < 1) return '\0';
 else {
  na = nc = ng = nt = no = ngap = 0;

  for (index = 0; index < length; index++) {
   if (column [index] == 'A') na++;
   else if (column [index] == 'C') nc++;
   else if (column [index] == 'G') ng++;
   else if (column [index] == 'T') nt++;
   else if (column [index] == GAP_SYMBOL) ngap++;
   else no++;
  }
  if ((ngap > 0) && (gaps_treatment == PROMOTE_GAP)) return GAP_SYMBOL;
  else {
   total = length;
   if ((ngap > 0) && (gaps_treatment == PROHIBIT_GAP)) {
    total = length - ngap; ngap = 0;
   }
   if ((na > nc) && (na > ng) && (na > nt) && (na > no) && (na > ngap))
    return 'A';
   else if ((nc > na) && (nc > ng) && (nc > nt) && (nc > no) && (nc > ngap))
    return 'C';
   else if ((ng > na) && (ng > nc) && (ng > nt) && (ng > no) && (ng > ngap))
    return 'G';
   else if ((nt > na) && (nt > nc) && (nt > ng) && (nt > no) && (nt > ngap))
    return 'T';
   else if ((ngap > na) && (ngap > nc) && (ngap > ng) && (ngap > nt) &&
            (ngap > no)) return GAP_SYMBOL;
   else if ((ngap >= na) && (ngap >= nc) && (ngap >= ng) && (ngap >= nt) &&
            (ngap >= no)) return 'N';
   else
    if ((no >= na) && (no >= nc) && (no >= ng) && (no >= nt) && (no >= ngap)) {
     if (no == 0) return 'N';
     else {
      single = TRUE; amb = '\0';
      for (index = 0; index < length; index++) {
       if ((column [index] != 'A') && (column [index] != 'C') &&
          (column [index] != 'G') && (column [index] != 'T') &&
           (column [index] != GAP_SYMBOL)) {
        if (amb == '\0') amb = column [index]; else single = FALSE;
       }
      }
      if (single) {
       if ((no > na) && (no > nc) && (no > ng) && (no > nt) && (no > ngap))
        return amb;
       else {
        if (amb == 'N') return 'N';
        else if ((amb == 'W') && (no > nc) && (no > ng)) return 'W';
        else if ((amb == 'Y') && (no > na) && (no > ng)) return 'Y';
        else if ((amb == 'S') && (no > na) && (no > nt)) return 'S';
        else if ((amb == 'R') && (no > nc) && (no > nt)) return 'R';
        else if ((amb == 'M') && (no > ng) && (no > nt)) return 'M';
        else if ((amb == 'K') && (no > na) && (no > nc)) return 'K';
        else if ((amb == 'B') && (no > na)) return 'B';
        else if ((amb == 'D') && (no > nc)) return 'D';
        else if ((amb == 'H') && (no > ng)) return 'H';
        else if ((amb == 'V') && (no > nt)) return 'V';
        else if ((amb == 'W') && (no > nc)) return 'D';
        else if ((amb == 'W') && (no > ng)) return 'H';
        else if ((amb == 'Y') && (no > na)) return 'B';
        else if ((amb == 'Y') && (no > ng)) return 'H';
        else if ((amb == 'S') && (no > na)) return 'B';
        else if ((amb == 'S') && (no > nt)) return 'V';
        else if ((amb == 'R') && (no > nc)) return 'D';
        else if ((amb == 'R') && (no > nt)) return 'V';
        else if ((amb == 'M') && (no > ng)) return 'H';
        else if ((amb == 'M') && (no > nt)) return 'V';
        else if ((amb == 'K') && (no > na)) return 'B';
        else if ((amb == 'K') && (no > nc)) return 'D';
        else return 'N';
       }
      }
      else {                   /* More than one ambiguity code in the column */
       if ((no - 1 >= na) && (no - 1 >= nc) && (no - 1 >= ng) &&
           (no - 1 >= nt) && (no - 1 >= ngap)) {
        return 'N';  /* ### To be refined to a better resolution, though ### */
       }
       else {
        if ((ngap > na) && (ngap > nc) && (ngap > ng) && (ngap > nt))
         return GAP_SYMBOL;
        else if ((ngap >= na) && (ngap >= nc) && (ngap >= ng) && (ngap >= nt))
         return 'N';
        else if ((na > nc) && (na > ng) && (na > nt)) return 'A';
        else if ((nc > na) && (nc > ng) && (nc > nt)) return 'C';
        else if ((ng > na) && (ng > nc) && (ng > nt)) return 'G';
        else if ((nt > na) && (nt > nc) && (nt > ng)) return 'T';
        else if ((na == nc) && (na > ng) && (na > nt)) return 'M';
        else if ((na == ng) && (na > nc) && (na > nt)) return 'R';
        else if ((na == nt) && (na > ng) && (na > nt)) return 'W';
        else if ((nc == ng) && (nc > na) && (na > nt)) return 'S';
        else if ((nc == nt) && (nc > na) && (na > ng)) return 'Y';
        else if ((ng == nt) && (ng > na) && (ng > nc)) return 'K';
        else if ((na == nc) && (nc == ng) && (ng > nt)) return 'V';
        else if ((na == nc) && (nc == nt) && (nt > ng)) return 'H';
        else if ((na == ng) && (ng == nt) && (nt > nc)) return 'D';
        else if ((nc == ng) && (ng == nt) && (nt > na)) return 'B';
        else return 'N';
       }
      }
     }
   }
   else {  /* No single character in majority, but not with gap or ambiguity */
    if ((na == nc) && (na > ng) && (na > nt)) return 'M';
    else if ((na == ng) && (na > nc) && (na > nt)) return 'R';
    else if ((na == nt) && (na > nc) && (na > ng)) return 'W';
    else if ((nc == ng) && (nc > na) && (nc > nt)) return 'S';
    else if ((nc == nt) && (nc > na) && (nc > ng)) return 'Y';
    else if ((ng == nt) && (ng > na) && (ng > nc)) return 'K';
    else if ((na == nc) && (nc == ng) && (na > nt)) return 'V';
    else if ((na == nc) && (nc == nt) && (na > ng)) return 'H';
    else if ((na == ng) && (ng == nt) && (na > nc)) return 'D';
    else if ((nc == ng) && (ng == nt) && (nc > na)) return 'B';
    else return 'N';
   }
  }
 }
}


