/*****************************************************************************/
/*                                                                           */
/* UNIT: abs_to_human  (Utility interface level library routine)             */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    07 SEP 94   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure interfaces user programs with the "ntl" library utilities;    */
/* determines all positions in the "human" sequence of an alignment that     */
/* correspond to those in the given list of absolute interval endpoints;     */
/* fixes the path name for the alignment file to be loaded; returns NULL if  */
/* everything was OK and corresponding positions in "human" have been found, */
/* character string with an error message otherwise                          */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl4.h"


/*****************************************************************************/
/*                                                                           */
/* Definitions section                                                       */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Unit constants                                                            */
/*****************************************************************************/



/*****************************************************************************/
/*                                                                           */
/* Code section                                                              */
/*                                                                           */
/*****************************************************************************/

/*****************************************************************************/
/*                                                                           */
/* PROCEDURE: abs_to_human                                                   */
/*                                                                           */
/* Central procedure for the unit; returns NULL if the alternative offset    */
/*   has been found and returned, diagnostic string otherwise                */
/*                                                                           */
/* Procedure abs_to_human determines offsets of pairs of positions specified */
/*   as absolute within the alignment, with respect to "humhbb_orig";        */
/*   positions are calculated as close as possible, and error made (if any)  */
/*   is returned together with offsets                                       */
/*                                                                           */
/* ASSUMPTION: Only one sequence in the alignment is "human"                 */

char *abs_to_human (twoint_ptr absolutes, fourint_ptr *offsets)
{
 errind exec_status; char *error_report;

 if ((exec_status = NTL3_Abs_To_Human (globin_filename ("Default_Alignment"), absolutes,
                                                offsets)) == NULL) return NULL;
 else {
  error_report = exec_status -> message; exec_status -> message = NULL;
  free (exec_status); return error_report;
 }
}

