/*****************************************************************************/
/*                                                                           */
/* UNIT: abs_corres_1  (Utility interface level library routine)             */
/*                                                                           */
/* Author: Nikola Stojanovic                                                 */
/*                                                                           */
/* Revision:    07 SEP 94   Version 1.0                                      */
/*                                                                           */
/* Function:                                                                 */
/*                                                                           */
/*   Procedure interfaces user programs with the "ntl" library utilities;    */
/* performs "absolute correspondence" determination for one position, given  */
/* by the reference origin and offset; fixes the path name for file names    */
/* needed by lower-level library routines; returns NULL if there were no     */
/* errors (and the list of corresponding offsets have been found), or string */
/* containing an error message otherwise                                     */
/*                                                                           */
/*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "ntl4.h"



/*****************************************************************************/
/*                                                                           */
/* Definitions section                                                       */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Unit constants                                                            */
/*****************************************************************************/



/*****************************************************************************/
/*                                                                           */
/* Code section                                                              */
/*                                                                           */
/*****************************************************************************/

/*****************************************************************************/
/*                                                                           */
/* PROCEDURE: abs_corres_1                                                   */
/*                                                                           */
/* Execution of unit code; returns NULL if no errors at lower levels         */

char *abs_corres_1 (char *reference, long int offset, int_ptr *result)
{
 errind exec_status; char *error_report;

 if ((exec_status = NTL3_Abs_Corres_1 (reference, offset,
                                       globin_filename ("Origins"),
                                       globin_filename ("Default_Alignment"),
                                       result)) == NULL) return NULL;
 else {
  error_report = exec_status -> message; exec_status -> message = NULL;
  free (exec_status); return error_report;
 }
}

